#
# spec file for package rust-bindgen
#
# Copyright (c) 2023 SUSE LLC
# Copyright (c) 2023, Martin Hauke <mardnh@gmx.de>
# Copyright (c) 2024 Andreas Stieger <Andreas.Stieger@gmx.de>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           rust-bindgen
Version:        0.70.1
Release:        1.3
Summary:        Automatically generates Rust FFI bindings to C and C++ libraries
License:        BSD-3-Clause
Group:          Development/Languages/Rust
#Git-Clone:     https://github.com/rust-lang/rust-bindgen.git
URL:            https://rust-lang.github.io/rust-bindgen/
Source:         %{name}-%{version}.tar.zst
Source1:        vendor.tar.zst
BuildRequires:  cargo
BuildRequires:  cargo-packaging
BuildRequires:  rust

%description
Automatically generates Rust FFI bindings to C (and some C++) libraries.

%prep
%autosetup -p 1 -a 1

%build
%{cargo_build}

%install
install -D -m 0755 target/release/bindgen %{buildroot}%{_bindir}/bindgen

%files
%license LICENSE
%doc CHANGELOG.md README.md
%{_bindir}/bindgen

%changelog
* Wed Aug 21 2024 Andreas Stieger <andreas.stieger@gmx.de>
- Update to version 0.70.1:
  * Revert "Only trigger the publish workflow manually"
  * Fix `collapsible_match` clippy warning
  * Add `#[clippy::allow]` attribute to `const` layout tests
  * Fix creduce example
  * Fix creduce install link
  * Fix create-tag.yml
* Mon Aug 19 2024 Andreas Stieger <andreas.stieger@gmx.de>
- Update to version 0.70.0:
  * Fix generation of extern "C" blocks with llvm 18
  * Update shlex dependency (RUSTSEC-2024-0006, boo#1229375)
  * Try to avoid repr(packed) for explicitly aligned types when not
    needed
  * Support Float16
  * Fix alignment contribution from bitfields
  * Replace peeking_take_while by itertools
  * Add blocklist_var
  * Stabilize thiscall_abi
  * Allow older itertools
  * Add target mappings for riscv64imac and riscv32imafc.
  * Add a complex macro fallback API
  * Add option to use DST structs for flexible arrays
  * Add option to dynamically load variables
  * Add option in CLI to use rustified non-exhaustive enums
  * Remove which and lazy-static dependencies
  * Generate compile-time layout tests
  * Print bindgen-cli errors to stderr instead of stdout
  * Fix --formatter=prettyplease not working in bindgen-cli by
    adding prettyplease feature and enabling it by default for
    bindgen-cli
  * Fix --allowlist-item so anonymous enums are no longer ignored
  * Use clang_getFileLocation instead of clang_getSpellingLocation
    to fix clang-trun
  * Fix generated constants: f64::INFINITY, f64::NEG_ INFINITY,
    f64::NAN
  * Update tempfile and rustix due to GHSA-c827-hfw6-qwvm (boo#1229376)
* Wed Nov 15 2023 Paolo Perego <paolo.perego@suse.com>
- Updated to version 0.69.1
- Changed vendor directory archive format
* Sun Jan 15 2023 Martin Hauke <mardnh@gmx.de>
- Initial package, version 0.63.0
